//STATA commands for Shelef, Nadav G. "Unequal Ground", International Organization

use "Unequal ground, IO data, final.dta"

//partition and conflict crosstab tables
tab2 homelandclaim midpost if colony2==0, row chi
tab2 homelandclaim highost45 if colony2==0, row chi
tab2 homelandclaim cowwar if colony2==0, row chi
tab homelandclaim decade if colony2==0
tab homelandclaim region if colony2==0

//ttests for figure 1
ttest midpost if colony2==0, by(homelandclaim)
ttest highost45 if colony2==0, by(homelandclaim)
ttest cowwar if colony2==0, by(homelandclaim)


//homelands, MIDS, significant MIDS, and wars (table 3)

quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model1
quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model2
quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model3
esttab model1 model2 model3 using 3_DVs.tex, replace mtitles("MIDs" "Violent MIDs" "Wars") label wrap nodep booktabs nonum nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(All models contain fixed effects for every pair of region and decade. Robust standard errors clustered by dyad in parentheses.) 

// marginal effects of homelands on midpost//
quietly reg midpost  cincrat allydummy dyaddem capital_distance_log oil_gas coethnicity priormid homelandclaim i.regionfe_region_decade  if colony2==0, cluster(dyadid4)
quietly margins, dydx(cincrat allydummy dyaddem capital_distance_log oil_gas coethnicity priormid homelandclaim  ) atmeans
quietly marginsplot, recast(scatter) horizontal allsim plotopts(connect(i)) xline(0) xdimension(_deriv)
graph export mid_marginal_effect.png, replace

// marginal effects of homelands on violent mid//
quietly reg highost45  cincrat allydummy dyaddem capital_distance_log oil_gas coethnicity priormid homelandclaim i.regionfe_region_decade  if colony2==0, cluster(dyadid4)
quietly margins, dydx(cincrat allydummy dyaddem capital_distance_log oil_gas coethnicity priormid homelandclaim  ) atmeans
quietly marginsplot, recast(scatter) horizontal allsim plotopts(connect(i)) xline(0) xdimension(_deriv)
graph export highost45_marginal_effect.png, replace

// marginal effects of homelands on cowwar//
quietly reg cowwar  cincrat allydummy dyaddem capital_distance_log oil_gas coethnicity priormid homelandclaim i.regionfe_region_decade  if colony2==0, cluster(dyadid4)
quietly margins, dydx(cincrat allydummy dyaddem capital_distance_log oil_gas coethnicity priormid homelandclaim  ) atmeans
quietly marginsplot, recast(scatter) horizontal allsim plotopts(connect(i)) xline(0) xdimension(_deriv)
graph export war_marginal_effct.png, replace

//Alternative explanation1: just about borders (table5)
quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if huth_conflict==1 & colony2==0, cluster(dyadid4)
eststo model1
quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if huth_conflict==1 & colony2==0, cluster(dyadid4)
eststo model2
quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if huth_conflict==1 & colony2==0, cluster(dyadid4)
eststo model3
esttab model1 model2 model3 using 3_DVs_only_terrconflict.tex, replace nonum mtitles("MIDs" "Violent MIDs" "Wars") label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(All models contain fixed effects for every pair of region and decade. Robust standard errors clustered by dyad in parentheses.) 


//Alternative explanation2: Endogeneity test: coethnics on other side of the border before the border is drawn as a proxy for real homeland claims
quietly reg midpost potato_dominant priormid oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model1
quietly reg highost45 potato_dominant priormid oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model2
quietly reg cowwar potato_dominant priormid oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model3
esttab model1 model2 model3 using prior_coethnic_homeland_proxy.tex, replace nonum mtitles("All MIDs" "Violent MIDs" "Wars")  label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(All models contain fixed effects for every pair of region and decade. Robust standard errors clustered by dyad in parentheses.) 

//Appendix Tables
//summary stats
sutex midpost highost45 cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat if colony2==0, minmax labels file(summarystats) replace

//PWcorrelation matrix
corrtex homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat if colony2==0,  file(correlation_matrix.tex) replace dig(2) key(tab:correlation_matrix) noscreen

//Any MID and homelands
quietly reg  midpost homelandclaim i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model1
quietly reg midpost homelandclaim priormid i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model2
quietly reg midpost homelandclaim priormid coethnicity i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model3
quietly reg midpost homelandclaim priormid coethnicity oil_gas i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model4
quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model5
quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model6
quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model7
quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model8
esttab model1 model2 model3 model4 model5 model6 model7 model8 using table3.tex, replace nomtit label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(All models contain fixed effects for every pair of region and decade. Robust standard errors clustered by dyad in parentheses.) 

//Violent MID and homelands
quietly reg  highost45 homelandclaim i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model1
quietly reg highost45 homelandclaim priormid i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model2
quietly reg highost45 homelandclaim priormid coethnicity i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model3
quietly reg highost45 homelandclaim priormid coethnicity oil_gas i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model4
quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model5
quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model6
quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model7
quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model8
esttab model1 model2 model3 model4 model5 model6 model7 model8 using bigtable_viol_mids.tex, replace nomtit label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(All models contain fixed effects for every pair of region and decade. Robust standard errors clustered by dyad in parentheses.) 


//cowwar and homelands
quietly reg  cowwar homelandclaim i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model1
quietly reg cowwar homelandclaim priormid i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model2
quietly reg cowwar homelandclaim priormid coethnicity i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model3
quietly reg cowwar homelandclaim priormid coethnicity oil_gas i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model4
quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model5
quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model6
quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model7
quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model8
esttab model1 model2 model3 model4 model5 model6 model7 model8 using bigtable_war.tex, replace nomtit label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(All models contain fixed effects for every pair of region and decade. Robust standard errors clustered by dyad in parentheses.) 


//Robustness to different operationalizations of IVs for midpost
quietly reg midpost homelandclaim cwprior coethnicity oil_gas capital_distance_log dyaddem allydummy  cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model1
quietly reg midpost homelandclaim tcprior45 coethnicity oil_gas capital_distance_log  dyaddem allydummy  cincrat  i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model2
quietly reg midpost homelandclaim violenttransfer coethnicity oil_gas capital_distance_log dyaddem allydummy  cincrat  i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model3
quietly reg midpost homelandclaim borderorigin coethnicity oil_gas capital_distance_log dyaddem allydummy  cincrat  i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model4
quietly reg midpost homelandclaim priormid coethnic_1 oil_gas capital_distance_log dyaddem allydummy  cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model5
quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem alliance  cincrat  i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model6
esttab model1 model2 model3 model4 model5 model6  using IV_Robustness_mid1.tex, replace nonum mtitles("(1)" "(2)" "(3)" "(4)" "(5)" "(7)") label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(Robust standard errors clustered by dyad in parentheses. All models contain fixed effects for every pair of decade and region.)  

quietly reg midpost homelandclaim priormid potato_dominant oil_gas capital_distance_log dyaddem allydummy  cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model31
esttab model31 using IV_Robustness_mid1.tex, append nonum mtitles("6") label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(Robust standard errors clustered by dyad in parentheses. All models contain fixed effects for every pair of decade and region. NOTE: THIS IS COLUMN 6 IN TABLE)  


quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log  dyaddem6 allydummy  cincrat  i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model7
quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log nondemdyad allydummy  cincrat  i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model8
quietly reg midpost homelandclaim priormid coethnicity oil_gas access dyaddem allydummy cincrat   i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model13
quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.five_year_region if colony2==0, cluster(dyadid4)
eststo model9
quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat   i.regionfe_region_decade if colony2==0, cluster(bordernum)
eststo model10
esttab model7 model8 model13 model9 model10 using IV_Robustness_mid2.tex, replace nonum mtitles("(8)" "(9)" "(10)" "(11)" "(12)") label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(Models 8-11: Robust standard errors clustered by dyad in parentheses. Model 12 clusters robust standard errors by border. Models 8-10 and 12 contain fixed effects for every pair of decade and region. Model 11 contains fixed effects for every 5-year period and region.)  

//Robustness to different operationalizations of IVs for highost45
quietly reg highost45 homelandclaim cwprior coethnicity oil_gas capital_distance_log dyaddem allydummy  cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model1
quietly reg highost45 homelandclaim tcprior45 coethnicity oil_gas capital_distance_log  dyaddem allydummy  cincrat  i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model2
quietly reg highost45 homelandclaim violenttransfer coethnicity oil_gas capital_distance_log dyaddem allydummy  cincrat  i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model3
quietly reg highost45 homelandclaim borderorigin coethnicity oil_gas capital_distance_log dyaddem allydummy  cincrat  i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model4
quietly reg highost45 homelandclaim priormid coethnic_1 oil_gas capital_distance_log dyaddem allydummy  cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model5
quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem alliance  cincrat  i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model6
esttab model1 model2 model3 model4 model5 model6  using IV_Robustness_Violentmid1.tex, replace nonum  mtitles("(1)" "(2)" "(3)" "(4)" "(5)" "(7)") label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(Robust standard errors clustered by dyad in parentheses. All models contain fixed effects for every pair of decade and region.)  

quietly reg highost45 homelandclaim priormid potato_dominant oil_gas capital_distance_log dyaddem allydummy  cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model31
esttab model31 using IV_Robustness_violentmid1.tex, append nonum mtitles("6") label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(Robust standard errors clustered by dyad in parentheses. All models contain fixed effects for every pair of decade and region. NOTE: THIS IS COLUMN 6 IN TABLE)  


quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log  dyaddem6 allydummy  cincrat  i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model7
quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log nondemdyad allydummy  cincrat  i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model8
quietly reg highost45 homelandclaim priormid coethnicity oil_gas access dyaddem allydummy cincrat   i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model13
quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.five_year_region if colony2==0, cluster(dyadid4)
eststo model9
quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat   i.regionfe_region_decade if colony2==0, cluster(bordernum)
eststo model10
esttab model7 model8 model13 model9 model10 using IV_Robustness_violentmid2.tex, replace nonum mtitles("(8)" "(9)" "(10)" "(11)" "(12)") label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(Models 8-11: Robust standard errors clustered by dyad in parentheses. Model 12 clusters robust standard errors by border. Models 8-10 and 12 contain fixed effects for every pair of decade and region. Model 11 contains fixed effects for every 5-year period and region.)  


//Robustness to different operationalizations of IVs for cowwar
quietly reg cowwar homelandclaim cwprior coethnicity oil_gas capital_distance_log dyaddem allydummy  cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model1
quietly reg cowwar homelandclaim tcprior45 coethnicity oil_gas capital_distance_log  dyaddem allydummy  cincrat  i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model2
quietly reg cowwar homelandclaim violenttransfer coethnicity oil_gas capital_distance_log dyaddem allydummy  cincrat  i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model3
quietly reg cowwar homelandclaim borderorigin coethnicity oil_gas capital_distance_log dyaddem allydummy  cincrat  i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model4
quietly reg cowwar homelandclaim priormid coethnic_1 oil_gas capital_distance_log dyaddem allydummy  cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model5
quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem alliance  cincrat  i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model6
esttab model1 model2 model3 model4 model5 model6  using IV_Robustness_war1.tex, replace nonum  mtitles("(1)" "(2)" "(3)" "(4)" "(5)" "(7)")  label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(Robust standard errors clustered by dyad in parentheses. All models contain fixed effects for every pair of decade and region.)  

quietly reg cowwar homelandclaim priormid potato_dominant oil_gas capital_distance_log dyaddem allydummy  cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model31
esttab model31 using IV_Robustness_war1.tex, append nonum  mtitles("(6)") label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(Robust standard errors clustered by dyad in parentheses. All models contain fixed effects for every pair of decade and region. NOTE: THIS IS COLUMN 6 IN TABLE)  

quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log  dyaddem6 allydummy  cincrat  i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model7
quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log nondemdyad allydummy  cincrat  i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model8
quietly reg cowwar homelandclaim priormid coethnicity oil_gas access dyaddem allydummy cincrat   i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model13
quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.five_year_region if colony2==0, cluster(dyadid4)
eststo model9
quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat   i.regionfe_region_decade if colony2==0, cluster(bordernum)
eststo model10
esttab model7 model8 model13 model9 model10 using IV_Robustness_war2.tex, replace nonum mtitles("(8)" "(9)" "(10)" "(11)" "(12)") label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(Models 8-11: Robust standard errors clustered by dyad in parentheses. Model 12 clusters robust standard errors by border. Models 8-10 and 12 contain fixed effects for every pair of decade and region. Model 11 contains fixed effects for every 5-year period and region.)  

//robustness to logit
logit midpost homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model1
reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model5
logit highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model13
reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model53
logit cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model2
reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model3
esttab model1 model5 model13 model53 model2 model3 using xtlogit_fe_strict.tex, replace mtitles("MID, logit" "MID, linear" "Violent MID, logit" "Violent MID, linear" "War, logit" "War, linear" ) nonum label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(All models contain fixed effects for every pair of region and decade. Robust standard errors clustered by dyad in parentheses.) 


//MID ROBUSTNESS TO SAMPLE CHOICES AND CODING DECISIONS
quietly reg midpost homelandclaim_stateonly priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model13
quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony2==0 & loseentry_alt==0, cluster(dyadid4)
eststo model91
quietly reg midpost arab_homeland_yes priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model1
quietly reg midpost palestine_homeland priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model27
quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  i.regionfe_region_decade, cluster(dyadid4)
eststo model3
quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony3==0, cluster(dyadid4)
eststo model97
quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  i.regionfe_region_decade if reciprocal_claim_zero==0 & colony2==0, cluster(dyadid4)
eststo model5
quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  i.regionfe_region_decade if high_dfbeta_midpost!=1 & colony2==0, cluster(dyadid4)
eststo model7
esttab model13 model91 model1 model27 model3 model97 model5 model7 using sample_robust.tex, replace mtitles("Excl. non-state claims" "Excl. state entry" "Incl. `Arab Homeland'" "Incl. Arab claims to Palestine" "Incl. decolonization" "Excl. incomplete decolonization" "Excl. reciprocal claim"  "Excl. high DFBETA") label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(All models contain fixed effects for every pair of region and decade. Robust standard errors clustered by dyad in parentheses.) 

//part 2
quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat   i.regionfe_region_decade if region!=2 & colony2==0, cluster(dyadid4)
eststo model11
quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.fe_region_decade_alt_region  if colony2==0, cluster(dyadid4)
eststo model1
	//RECODING HOMELANDCLAIM=0 IF INSTRUMENTAL==1 OR ARTICULATED ONLY AFTER 5 YEARS.
quietly reg midpost homeland_not_instrumental priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model7
	//excluding german cases
quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if no_united_germany!=1  & colony2==0, cluster(dyadid4)
eststo model21
quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if no_divided_germany !=1  & colony2==0, cluster(dyadid4)
eststo model23
quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if no_germany !=1  & colony2==0, cluster(dyadid4)
eststo model25
esttab  model11 model1 model7 model21 model23 model25  using sample_robust2.tex, replace mtitles("Excl. Europe" "Alt. region coding" "Recode likely instrumental claims as no claim" "Excl. united Germany" "Excl. divided Germany" "Excl. all Germany")  label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(All models contain fixed effects for every pair of region and decade. Robust standard errors clustered by dyad in parentheses.) 

//VIOLENT MID ROBUSTNESS TO SAMPLE CHOICES- Arab homeland yes (1-2), INCLUDING DECOLONIZATION(3,4) EXCLUDING RECIPRORCAL CLAIMS (5,6), EXCLUDING HIGH DFBETA (7,8) FOR BOTH MIDPOST AND COWWAR, (9, 10), excluding europe
quietly reg highost45 homelandclaim_stateonly priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model13
quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony2==0 & loseentry_alt==0, cluster(dyadid4)
eststo model92
quietly reg highost45 arab_homeland_yes priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model1
quietly reg highost45 palestine_homeland priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model27
quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  i.regionfe_region_decade, cluster(dyadid4)
eststo model3
quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony3==0, cluster(dyadid4)
eststo model98
quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  i.regionfe_region_decade if reciprocal_claim_zero==0 & colony2==0, cluster(dyadid4)
eststo model5
quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  i.regionfe_region_decade if high_dfbeta_violentmid!=1 & colony2==0, cluster(dyadid4)
eststo model7
esttab model13 model92 model1 model27 model3 model98 model5 model7 using sample_violentMID_robust.tex, replace mtitles("Excl. non-state claims" "Excl. state entry" "Incl. `Arab Homeland'" "Incl. Arab claims to Palestine" "Incl. decolonization" "Excl. incomplete decolonization" "Excl. reciprocal claim"  "Excl. high DFBETA" ) label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(All models contain fixed effects for every pair of region and decade. Robust standard errors clustered by dyad in parentheses.) 

//part 2
quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat   i.regionfe_region_decade if region!=2 & colony2==0, cluster(dyadid4)
eststo model11
quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.fe_region_decade_alt_region  if colony2==0, cluster(dyadid4)
eststo model1
	//RECODING HOMELANDCLAIM=0 IF INSTRUMENTAL==1 OR ARTICULATED ONLY AFTER 5 YEARS.
quietly reg highost45 homeland_not_instrumental priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model7
	//excluding german cases
quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if no_united_germany!=1  & colony2==0, cluster(dyadid4)
eststo model21
quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if no_divided_germany !=1  & colony2==0, cluster(dyadid4)
eststo model23
quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if no_germany !=1  & colony2==0, cluster(dyadid4)
eststo model25
esttab  model11 model1 model7 model21 model23 model25  using sample_violentMID_robust2.tex, replace mtitles("Excl. Europe" "Alt. region coding" "Recode likely instrumental claims as no claim" "Excl. united Germany" "Excl. divided Germany" "Excl. all Germany")  label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(All models contain fixed effects for every pair of region and decade. Robust standard errors clustered by dyad in parentheses.) 

//COWWAR - ROBUSTNESS TO SAMPLE CHOICES
quietly reg cowwar homelandclaim_stateonly priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model12
quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony2==0 & loseentry_alt==0, cluster(dyadid4)
eststo model93
quietly reg cowwar arab_homeland_yes priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model2
quietly reg highost45 palestine_homeland priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model27
quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  i.regionfe_region_decade, cluster(dyadid4)
eststo model4
quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony3==0, cluster(dyadid4)
eststo model99
quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  i.regionfe_region_decade if reciprocal_claim_zero==0 & colony2==0, cluster(dyadid4)
eststo model6
quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  i.regionfe_region_decade if high_dfbeta_war!=1 & colony2==0, cluster(dyadid4)
eststo model8
esttab model12 model93 model2 model27 model4 model99 model6 model8 using sample_war_robust.tex, replace mtitles("Excl. non-state claims" "Excl. state entry" "Incl. `Arab Homeland'" "Incl. Arab claims to Palestine" "Incl. decolonization" "Excl. incomplete decolonization" "Excl. reciprocal claim" "Excl. high DFBETA") label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(All models contain fixed effects for every pair of region and decade. Robust standard errors clustered by dyad in parentheses.) 

//part 2
quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat   i.regionfe_region_decade if region!=2 & colony2==0, cluster(dyadid4)
eststo model12
quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.fe_region_decade_alt_region if colony2==0, cluster(dyadid4)
eststo model6
	//RECODING HOMELANDCLAIM=0 IF INSTRUMENTAL==1 OR ARTICULATED ONLY AFTER 5 YEARS.
quietly reg cowwar homeland_not_instrumental priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model8
	//excluding german cases
quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if no_united_germany!=1  & colony2==0, cluster(dyadid4)
eststo model22
quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if no_divided_germany !=1  & colony2==0, cluster(dyadid4)
eststo model24
quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if no_germany !=1  & colony2==0, cluster(dyadid4)
eststo model26
esttab  model12 model6 model8 model22 model24 model26 using sample_war_robust2.tex, replace mtitles("Excl. Europe" "Alt. region coding" "Recode likely instrumental claims as no claim" "Excl. united Germany" "Excl. divided Germany" "Excl. all Germany")  label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(All models contain fixed effects for every pair of region and decade. Robust standard errors clustered by dyad in parentheses.) 

//Robustness to why border was drawn: excluding reason for new border one at a time
	//leaving out origin_treaty
quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat origin_prior_admin origin_prior_col origin_icj origin_war i.regionfe_region_decade if  colony2==0, cluster(dyadid4)
eststo model1
quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat origin_prior_admin origin_prior_col origin_icj origin_war i.regionfe_region_decade if  colony2==0, cluster(dyadid4)
eststo model2
quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat origin_prior_admin origin_prior_col origin_icj origin_war i.regionfe_region_decade if  colony2==0, cluster(dyadid4)
eststo model3
	//leaving out origin_icj
quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat origin_prior_admin origin_prior_col origin_treaty origin_war i.regionfe_region_decade if  colony2==0, cluster(dyadid4)
eststo model4
quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat origin_prior_admin origin_prior_col origin_treaty origin_war i.regionfe_region_decade if  colony2==0, cluster(dyadid4)
eststo model5
quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat origin_prior_admin origin_prior_col origin_treaty origin_war i.regionfe_region_decade if  colony2==0, cluster(dyadid4)
eststo model6
	//leaving out origin_prior_admin
quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  origin_prior_col origin_treaty origin_icj origin_war i.regionfe_region_decade if  colony2==0, cluster(dyadid4)
eststo model7
quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  origin_prior_col origin_treaty origin_icj origin_war i.regionfe_region_decade if  colony2==0, cluster(dyadid4)
eststo model8
quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat origin_prior_col origin_treaty origin_icj origin_war i.regionfe_region_decade if  colony2==0, cluster(dyadid4)
eststo model9
esttab model1 model2 model3 model4 model5 model6 model7 model8 model9 using Robustness_origin.tex, replace mtitles("All MIDs" "Violent MIDs" "Wars" "All MIDs" "Violent MIDs" "Wars" "All MIDs" "Violent MIDs" "Wars")  label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(Robust standard errors clustered by dyad in parentheses. All models contain fixed effects for every pair of decade and region.)  
	//leaving out origin_prior_col
quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  origin_prior_admin origin_treaty origin_icj origin_war i.regionfe_region_decade if  colony2==0, cluster(dyadid4)
eststo model10
quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  origin_prior_admin origin_treaty origin_icj origin_war i.regionfe_region_decade if  colony2==0, cluster(dyadid4)
eststo model11
quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat origin_prior_admin origin_treaty origin_icj origin_war i.regionfe_region_decade if  colony2==0, cluster(dyadid4)
eststo model12
	//leaving out origin_war
quietly reg midpost homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  origin_prior_admin origin_treaty origin_icj origin_prior_col i.regionfe_region_decade if  colony2==0, cluster(dyadid4)
eststo model13
quietly reg highost45 homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  origin_prior_admin origin_treaty origin_icj origin_prior_col i.regionfe_region_decade if  colony2==0, cluster(dyadid4)
eststo model14
quietly reg cowwar homelandclaim priormid coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat origin_prior_admin origin_treaty origin_icj origin_prior_col i.regionfe_region_decade if  colony2==0, cluster(dyadid4)
eststo model15
esttab model10 model11 model12 model13 model14 model15 using Robustness_origin_cont.tex, replace mtitles("All MIDs" "Violent MIDs" "Wars" "All MIDs" "Violent MIDs" "Wars") label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(Robust standard errors clustered by dyad in parentheses. All models contain fixed effects for every pair of decade and region.)  

//non-directed dyad table
use "Unequal ground data, border as unit.dta" 
quietly reg midpost border_homelandclaim priormid border_coethnicity border_oil border_distance dyaddem allydummy border_capability i.regionfe_region_decade if colony2==0 & n1==1, robust
eststo model1
quietly reg highost45 border_homelandclaim priormid border_coethnicity border_oil border_distance dyaddem allydummy border_capability i.regionfe_region_decade if colony2==0 & n1==1, robust
eststo model2
quietly reg cowwar border_homelandclaim priormid border_coethnicity border_oil border_distance dyaddem allydummy border_capability i.regionfe_region_decade if colony2==0 & n1==1, robust
eststo model3
esttab model1 model2 model3 using non-directed_dyad.tex, replace nonum mtitles("All MIDs" "Violent MIDs" "Wars") label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(All models contain fixed effects for every pair of region and decade and robust standard errors.) 
use "Unequal ground, IO data, final.dta"

//endogeneity tests: no previous conflict
quietly reg midpost homelandclaim coethnicity material_value dyaddem allydummy cincrat i.regionfe_region_decade if priormid==0 & colony2==0, cluster(dyadid4)
eststo model1
quietly reg highost45 homelandclaim coethnicity material_value dyaddem allydummy cincrat i.regionfe_region_decade if priormid==0 & colony2==0, cluster(dyadid4)
eststo model2
quietly reg cowwar homelandclaim coethnicity material_value dyaddem allydummy cincrat i.regionfe_region_decade if priormid==0 & colony2==0, cluster(dyadid4)
eststo model3
esttab model1 model2 model3 using endogeneity_subsamples3a.tex, replace mtitles("All MIDs" "Violent MIDs" "Wars") label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(All models contain fixed effects for every pair of region and decade. Robust standard errors clustered by dyad in parentheses.)  nonumbers

//robustness of endogeneity tests- no prior conflict 4 ways, for MID, violent MID and war
quietly reg midpost homelandclaim coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  i.regionfe_region_decade if tcprior45==0  & colony2==0, cluster(dyadid4)
eststo model1
esttab model1 using endogeneity_subsample_robustness2.tex, replace mtitles("Excl. prior terr. transfer") nonumbers label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(All models contain fixed effects for every pair of region and decade. Robust standard errors clustered by dyad in parentheses.) 
quietly reg midpost homelandclaim coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  i.regionfe_region_decade if violenttransfer==0  & colony2==0, cluster(dyadid4)
eststo model3
esttab model3 using endogeneity_subsample_robustness2.tex, append mtitles("Excl. prior violent terr. transfer") nonumbers label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(All models contain fixed effects for every pair of region and decade. Robust standard errors clustered by dyad in parentheses.) 
quietly reg midpost homelandclaim coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat   i.regionfe_region_decade if cwprior==0  & colony2==0, cluster(dyadid4)
eststo model5
esttab model5 using endogeneity_subsample_robustness2.tex, append mtitles("Excl. prior civil war" ) nonumbers label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(All models contain fixed effects for every pair of region and decade. Robust standard errors clustered by dyad in parentheses.) 
quietly reg highost45 homelandclaim coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  i.regionfe_region_decade if tcprior45==0  & colony2==0, cluster(dyadid4)
eststo model1
esttab model1 using endogeneity_subsample_robustness2.tex, append mtitles("Excl. prior terr. transfer") nonumbers label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(All models contain fixed effects for every pair of region and decade. Robust standard errors clustered by dyad in parentheses.) 
quietly reg highost45 homelandclaim coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  i.regionfe_region_decade if violenttransfer==0  & colony2==0, cluster(dyadid4)
eststo model3
esttab model3 using endogeneity_subsample_robustness2.tex, append mtitles("Excl. prior violent terr. transfer") nonumbers label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(All models contain fixed effects for every pair of region and decade. Robust standard errors clustered by dyad in parentheses.) 
quietly reg highost45 homelandclaim coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat   i.regionfe_region_decade if cwprior==0  & colony2==0, cluster(dyadid4)
eststo model5
esttab model5 using endogeneity_subsample_robustness2.tex, append mtitles("Excl. prior civil war" ) nonumbers label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(All models contain fixed effects for every pair of region and decade. Robust standard errors clustered by dyad in parentheses.) 
quietly reg cowwar homelandclaim coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  i.regionfe_region_decade if tcprior45==0  & colony2==0, cluster(dyadid4)
eststo model1
esttab model1 using endogeneity_subsample_robustness2.tex, append mtitles("Excl. prior terr. transfer") nonumbers label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(All models contain fixed effects for every pair of region and decade. Robust standard errors clustered by dyad in parentheses.) 
quietly reg cowwar homelandclaim coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat  i.regionfe_region_decade if violenttransfer==0  & colony2==0, cluster(dyadid4)
eststo model3
esttab model3 using endogeneity_subsample_robustness2.tex, append mtitles("Excl. prior violent terr. transfer") nonumbers label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(All models contain fixed effects for every pair of region and decade. Robust standard errors clustered by dyad in parentheses.) 
quietly reg cowwar homelandclaim coethnicity oil_gas capital_distance_log dyaddem allydummy cincrat   i.regionfe_region_decade if cwprior==0  & colony2==0, cluster(dyadid4)
eststo model5
esttab model5 using endogeneity_subsample_robustness2.tex, append mtitles("Excl. prior civil war" ) nonumbers label wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(All models contain fixed effects for every pair of region and decade. Robust standard errors clustered by dyad in parentheses.) 


//Predictors of homeland claims
quietly reg homelandclaim priormid potato_dominant oil_gas  capital_distance_log dyaddem allydummy cincrat i.regionfe_region_decade if colony2==0, cluster(dyadid4)
eststo model1
esttab model1 using homeland_as_y.tex, replace mtitles("Homeland status") label nonum wrap nodep booktabs nogaps se(%8.3g) b(%8.4g) starlevels(* 0.10 ** 0.05 *** 0.01) stat(N , labels("N")) sfmt(%8.3g) note(All models contain fixed effects for every pair of region and decade. Robust standard errors clustered by dyad in parentheses.) 

